@@ -671,7 +671,7 @@ void GLCreateDownwash(void *pQMiarex, CWing *pWing, CWOpp *pWOpp, int List)
 	double sina = -sin(pWOpp->m_Alpha*PI/180.0);
 	double cosa =  cos(pWOpp->m_Alpha*PI/180.0);
 	double sign;
-	factor = pMiarex->m_VelocityScale/20.0;
+	factor = pMiarex->m_VelocityScale/100.0;
 
 	//DOWNWASH
 	glNewList(List,GL_COMPILE);
@@ -713,8 +713,8 @@ void GLCreateDownwash(void *pQMiarex, CWing *pWing, CWOpp *pWOpp, int List)
 					{
 						glVertex3d(xt, yt, zt);
 						glVertex3d(xt + amp * cos(dih)* sina,
-								   yt + amp * sin(dih),
-								   zt + amp * cos(dih)* cosa);
+								 yt + amp * sin(dih),
+								 zt + amp * cos(dih)* cosa);
 					}
 					glEnd();
 				}
@@ -731,8 +731,8 @@ void GLCreateDownwash(void *pQMiarex, CWing *pWing, CWOpp *pWOpp, int List)
 						amp *= factor;
 
 						glVertex3d(xt + amp * cos(dih)* sina,
-								   yt + amp * sin(dih),
-								   zt + amp * cos(dih)* cosa);
+								 yt + amp * sin(dih),
+								 zt + amp * cos(dih)* cosa);
 					}
 				}
 				glEnd();
@@ -830,8 +830,6 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 	else if(Vstyle == 4) 	VDash = 0x7E66;
 	else					VDash = 0xFFFF;
 
-
-
 	Ir = Icolor.redF();
 	Ig = Icolor.greenF();
 	Ib = Icolor.blueF();
@@ -849,11 +847,11 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 		glEnable (GL_LINE_STIPPLE);
 		glPolygonMode(GL_FRONT,GL_LINE);
 
-		double q0 = 0.5*pWPolar->m_Density * pWPolar->m_WArea*pWOpp->m_QInf*pWOpp->m_QInf;
+		double q0 = 0.5 * pWPolar->m_Density * pWPolar->m_WArea * pWOpp->m_QInf * pWOpp->m_QInf;
 
 		if(pWOpp)
 		{
-			if(pWOpp->m_AnalysisMethod==1)
+			if(pWOpp->m_AnalysisMethod==LLTMETHOD)
 			{
 				for (i=1; i<pWOpp->m_NStation; i++)
 				{
@@ -977,8 +975,8 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 							{
 								glVertex3d(C.x, C.y, C.z);
 								glVertex3d(C.x + amp1*cosa * cosb,
-										   C.y + amp1*cosa * sinb,
-										   C.z - amp1*sina);
+										 C.y + amp1*cosa * sinb,
+										 C.z - amp1*sina);
 							}
 							glEnd();
 						}
@@ -993,17 +991,17 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 								{
 									glVertex3d(C.x, C.y, C.z);
 									glVertex3d(C.x + amp2*cosa*cosb,
-											   C.y + amp2*cosa*sinb,
-											   C.z - amp2*sina);
+											 C.y + amp2*cosa*sinb,
+											 C.z - amp2*sina);
 								}
 								else
 								{
 									glVertex3d(C.x + amp1*cosa*cosb,
-											   C.y + amp1*cosa*sinb,
-											   C.z - amp1*sina);
+											 C.y + amp1*cosa*sinb,
+											 C.z - amp1*sina);
 									glVertex3d(C.x + (amp1+amp2)*cosa*cosb,
-											   C.y + (amp1+amp2)*cosa*sinb,
-											   C.z - (amp1+amp2)*sina);
+											 C.y + (amp1+amp2)*cosa*sinb,
+											 C.z - (amp1+amp2)*sina);
 								}
 							}
 							glEnd();
@@ -1030,8 +1028,8 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 									amp = q0*(pWOpp->m_ICd[i])*pWOpp->m_Chord[i]/pWing->m_MAChord;
 									amp *= pMiarex->m_DragScale/coef;
 									glVertex3d(C.x + amp*cosa*cosb,
-											   C.y + amp*cosa*sinb,
-											   C.z - amp*sina);
+											 C.y + amp*cosa*sinb,
+											 C.z - amp*sina);
 									i++;
 								}
 							}
@@ -1058,8 +1056,8 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 									amp *= pMiarex->m_DragScale/coef;
 
 									glVertex3d(C.x + amp*cosa*cosb,
-											   C.y + amp*cosa*sinb,
-											   C.z - amp*sina);
+											 C.y + amp*cosa*sinb,
+											 C.z - amp*sina);
 									i++;
 								}
 							}
@@ -1085,8 +1083,8 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 									amp = q0*(pWOpp->m_ICd[i])*pWOpp->m_Chord[i]/pWing->m_MAChord;
 									amp *= pMiarex->m_DragScale/coef;
 									glVertex3d(C.x + amp*cosa*cosb,
-											   C.y + amp*cosa*sinb,
-											   C.z - amp*sina);
+											 C.y + amp*cosa*sinb,
+											 C.z - amp*sina);
 									i++;
 								}
 							}
@@ -1113,8 +1111,8 @@ void GLCreateDrag(void *pQMiarex, CWing *pWing, CWPolar* pWPolar, CWOpp *pWOpp,
 									amp *= pMiarex->m_DragScale/coef;
 
 									glVertex3d(C.x + amp*cosa*cosb,
-											   C.y + amp*cosa*sinb,
-											   C.z - amp*sina);
+											 C.y + amp*cosa*sinb,
+											 C.z - amp*sina);
 									i++;
 								}
 							}
@@ -1895,7 +1893,7 @@ void GLCreateSurfSpeeds(void *pQMiarex, CPanel *pPanel, CWPolar *pWPolar, CWOpp
 	CVector C, V, VT;
 	CVector RefPoint(0.0,0.0,0.0);
 
-	factor = 0.2;
+	factor = pMiarex->m_VelocityScale/100.0;
 	CPOpp *pPOpp = pMiarex->m_pCurPOpp;
 	if(pPOpp)
 	{
@@ -1947,7 +1945,6 @@ void GLCreateSurfSpeeds(void *pQMiarex, CPanel *pPanel, CWPolar *pWPolar, CWOpp
 					pMiarex->m_pPanelDlg->GetSpeedVector(C, Mu, Sigma, V);
 
 					VT += V;
-					VT *= pMiarex->m_VelocityScale/100.0;
 //					if(!pWPolar->m_bTiltedGeom)
 						C.RotateY(RefPoint, pWOpp->m_Alpha);
 						//Tilt the geometry w.r.t. sideslip
@@ -2307,7 +2304,7 @@ void GLDrawWingLegend(void *pQMiarex, CWing *pWing, CPlane *pPlane, CWPolar *pWP
 	QFontMetrics fm(pMainFrame->m_TextFont);
 	dD = fm.height();//pixels
 
-// Write wing data
+	// Write wing data
 
 	total = 12;
 	if(pWPolar) total +=2;
@@ -2324,7 +2321,8 @@ void GLDrawWingLegend(void *pQMiarex, CWing *pWing, CPlane *pPlane, CWPolar *pWP
                 //pMiarex->m_GLList++;
 		glDisable(GL_LIGHTING);
 		glDisable(GL_LIGHT0);
-                glColor3d(pMainFrame->m_TextColor.redF(),pMainFrame->m_TextColor.greenF(),pMainFrame->m_TextColor.blueF());
+		glColor3d(pMainFrame->m_TextColor.redF(),pMainFrame->m_TextColor.greenF(),pMainFrame->m_TextColor.blueF());
+
 		if(pWing)
 		{
 			GetLengthUnit(length,pMainFrame->m_LengthUnit);
@@ -2362,8 +2360,8 @@ void GLDrawWingLegend(void *pQMiarex, CWing *pWing, CPlane *pPlane, CWPolar *pWP
 			pGLWidget->renderText(LeftPos, ZPos, Result+length, pMainFrame->m_TextFont);
 
 			ZPos +=dD;
-			double Area = pWing->m_ProjectedArea;
-			if(pPlane && pPlane->BiPlane()) Area+=pPlane->Wing2()->m_ProjectedArea;
+			double Area = pWing->m_PlanformArea;
+			if(pPlane && pPlane->BiPlane()) Area+=pPlane->Wing2()->m_PlanformArea;
 			str1 = QString(QObject::tr("Wing Area      = %1 ")).arg(Area * pMainFrame->m_m2toUnit, a,'f',b);
 			str1 +=surface;
 			pGLWidget->renderText(LeftPos, ZPos, str1, pMainFrame->m_TextFont);
