@@ -726,6 +726,8 @@ void PlaneDlg::SetParams()
 
 	if(m_pPlane->Body()) m_pctrlBody->setChecked(true);
 	else                  m_pctrlBody->setChecked(false);
+
+	m_pctrlBodyList->clear();
 	for(i=0; i<s_poaBody->size(); i++)
 	{
 		pBody = (CBody*)s_poaBody->at(i);
@@ -1013,6 +1015,7 @@ void PlaneDlg::SetupLayout()
 	QGroupBox *BodyBox = new QGroupBox(tr("Body"));
 	{
 		QHBoxLayout *BodyName = new QHBoxLayout;
+		QLabel *BodyWarning = new QLabel(tr("Warning:\nIncluding the body in the analysis is not recommended.\nCheck the guidelines for explanations."));
 		m_pctrlBody = new QCheckBox(tr("Body"));
 		m_pctrlEditBody = new QPushButton(tr("Edit..."));
 		m_pctrlBodyList = new QComboBox;
@@ -1038,6 +1041,7 @@ void PlaneDlg::SetupLayout()
 		BodyPos->addWidget(m_pctrlZBody,2,2);
 		BodyPos->addWidget(m_pctrlLen11,2,3);
 		QVBoxLayout *BodyLayout = new QVBoxLayout;
+		BodyLayout->addWidget(BodyWarning);
 		BodyLayout->addLayout(BodyName);
 		BodyLayout->addLayout(BodyPos);
 		BodyBox->setLayout(BodyLayout);
